@@ -17,13 +17,13 @@ class MarkClient:
 
   def get_server_status(self):
     print "- Get the status of the server"
-    parameters = {'method': 'executorStatus', 'id': 123}
+    parameters = {'method': 'status', 'id': 123}
     response = requests.post(self.server_url, data=json.dumps(parameters), proxies=self.proxy)
     if self.verbose:
       print "-- Status of the get_server_status request:"
       print "-- " + str(response.json())
     response_data = response.json()["result"]
-    print "-- Current Active Jobs: " + str(response_data["running"])
+    print "-- Current Active Jobs: " + str(response_data["executor.job.running"])
     return response_data
 
   def add_evidence(self, evidence_data):
